@@ -7,5 +7,6 @@ Check LICENSE for details.
 """
 
 class Command(object):
-	def __init__(self, verbose=False, **kwargs):
+	def __init__(self, verbose=False, jlinkexe='JLinkExe', **kwargs):
 		self.verbose = verbose
+		self.jlinkexe = jlinkexe
